@@ -2,10 +2,9 @@ import torch.nn as nn
 
 
 class DenoiserHead(nn.Module):
-    def __init__(self, head_type, loss_type, loss_weight):
+    def __init__(self, loss_type, loss_weight):
 
         super(DenoiserHead, self).__init__()
-        self.head_type = head_type
         self.loss_type = loss_type
         if loss_type == "l2":
             self.loss_func = nn.MSELoss(reduction='mean')
@@ -17,12 +16,7 @@ class DenoiserHead(nn.Module):
         self.loss_wight = loss_weight
 
     def forward(self, base_output):
-        if self.head_type == "supervise":
-            output = base_output
-        else:
-            raise TypeError
-
-        return output
+        return base_output
 
     def loss(self, base_output, target=None, mask=None):
         output = self.forward(base_output)
